/**
 * Copyright (c) 2007-2012 EBM WebSourcing, 2012-2017 Linagora
 * 
 * This program/library is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation, either version 2.1 of the License, or (at your
 * option) any later version.
 * 
 * This program/library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public License
 * for more details.
 * 
 * You should have received a copy of the GNU Lesser General Public License
 * along with this program/library; If not, see http://www.gnu.org/licenses/
 * for the GNU Lesser General Public License version 2.1.
 */
package org.ow2.petals.microkernel.api.container;

import org.ow2.petals.jbi.descriptor.original.generated.Jbi;
import org.ow2.petals.microkernel.api.communication.jndi.client.JNDIService;
import org.ow2.petals.microkernel.api.configuration.ConfigurationService;
import org.ow2.petals.microkernel.api.jbi.management.AdminService;
import org.ow2.petals.microkernel.api.jbi.messaging.RouterService;
import org.ow2.petals.microkernel.api.jbi.messaging.endpoint.EndpointDirectoryService;

/**
 * <p>
 * The ComponentContext needs to access some services such as the Router and so on. Those services are implemented by
 * Fractal components, that may dynamically change during the runtime.
 * </p>
 * <p>
 * Thus, the ComponentContext can not reference directly those services. Each time the ComponentContext uses those
 * services, it retrieves through this interface the good reference of the service. This interface is implemented by the
 * fractal component <code>Installer</code>.
 * </p>
 * 
 * @see org.ow2.petals.microkernel.container.lifecycle.Installer
 * @see org.ow2.petals.microkernel.container.lifecycle.ComponentLifeCycle
 * @author Adrien Louis - EBM WebSourcing
 * @author Nicolas Salatge - EBM WebSourcing
 */
public interface ComponentContextCommunication {

    /**
     * Gets the JBI Descriptor.
     * @return the JBI descriptor
     */
    public Jbi getJBIDescriptor();

    /**
     * The installation directory of the component.
     * 
     * @return the installation root
     */
    public String getInstallationRoot();

    /**
     * The working directory for the component.
     * 
     * @return the workspace root
     */
    public String getWorkspaceRoot();

    /**
     * Get the Admin service.
     * 
     * @return the admin service
     */
    public AdminService getAdminService();

    /**
     * Get the Container service.
     * 
     * @return the container service
     */
    public ContainerService getContainerService();

    /**
     * Get the Configuration service.
     */
    public ConfigurationService getConfigurationService();

    /**
     * Get the JNDI service.
     */
    public JNDIService getJNDIService();

    /**
     * Get the endpoint directory service.
     * 
     * @return the endpoint directory service
     */
    public EndpointDirectoryService getEndpointDirectory();

    /**
     * Get the Router service.
     * 
     * @return the router
     */
    public RouterService getRouterService();

}
